@@ -7,7 +7,7 @@
 
 @interface ASMModelSwarm: Swarm
 {
-//Simulation parameters
+  //Agent parameters
   int numBFagents;
   float initholding;
   double initialcash;
@@ -15,16 +15,18 @@
   double mincash;
   double intrate;
 
-  double baseline;
+  //Dividend parameters
+  double baseline;   //Also used by World.
   double mindividend;
   double maxdividend;
   double amplitude;
   int period;
 
+  //Specialist parameters
   double maxprice;
   double minprice;
   double taup;
-  BOOL exponentialMAs;
+  BOOL exponentialMAs;   //Also used by World.
   int sptype;
   int maxiterations;
   double minexcess;
@@ -33,8 +35,11 @@
   double etamin;
   double rea;
   double reb;
+
   int randomSeed;
 
+  //Agent parameters overridden by the BFagent.  
+  //These might be used for other agents that a user implements. 
   double tauv;          
   double lambda;
   double maxbid; 
