@@ -34,7 +34,7 @@
 
 -creditEarningsAndPayTaxes;
 -(double)constrainDemand: (double *)slope : (double)trialprice;
--(double)getPosition;
+-(double)getAgentPosition;
 -(double)getWealth;
 -(double)getCash;
 
