@@ -1,7 +1,7 @@
 // Code for a "bitstring forecaster" (BF) agent
 
 // +init
-//     initializes the class, setting parameters and allocating space
+//     Initializes the class, setting parameters and allocating space
 //     for arrays.
 //
 // +didInitialize
@@ -66,11 +66,9 @@
 #import "BFagent.h"
 #import "random.h"
 #import "World.h"
-
 #include <misc.h>
-#include <math.h>
 
-World * worldForAgent;
+extern World *worldForAgent;
 
 //Macros for bittables
 #define WORD(bit)	(bit>>4)
@@ -187,7 +185,7 @@ extern int ReadBitname(const char *variable, const struct keytable *table);
 // Read in general parameters
   params->numfcasts = 60;
   params->tauv = 50.0;
-  params->lambda = 0.5; 
+  params->lambda = 0.3; 
   params->maxbid = 10.0;
   params->mincount = 5;
   params->subrange = 0.5;
@@ -199,7 +197,7 @@ extern int ReadBitname(const char *variable, const struct keytable *table);
   params->c_max = 11.799979;
   params->newfcastvar = 4.000212; 
   params->initvar = 4.000212;
-  params->bitcost = 0.001;
+  params->bitcost = 0.01;
   params->maxdev = 100;
   params->individual = 0; 
   params->bitprob = 0.1;
@@ -262,7 +260,7 @@ extern int ReadBitname(const char *variable, const struct keytable *table);
     printf("The bitcost is too negative.");
 
 // Read in GA parameters
-  params->gafrequency = 500; 
+  params->gafrequency = 100; 
   params->firstgatime = 1000;
   params->poolfrac = 0.1;
   params->newfrac = 0.05;
