@@ -205,13 +205,14 @@
   strcat (paramFile, ctime (&runTime));
   for (i = 0; i < 256; i++)
     {
-      if (paramFile[i] == ' ')
+      if (paramFile[i] == ' ' || paramFile[i] == ':')
 	paramFile[i] = '_';
       if (paramFile[i] == '\n')
 	paramFile[i] = '\0';
     }
   
-  paramOutputFile = fopen(paramFile, "w");
+  if(!(paramOutputFile = fopen(paramFile, "w")))
+    abort();
 
   fprintf (paramOutputFile, "@begin\n");
   fprintf (paramOutputFile, "numBFagents %d\n",numBFagents);
@@ -270,13 +271,14 @@
   strcat (outputFile,ctime (&runTime));
   for (i = 0; i < 256; i++)
     {
-      if (outputFile[i] == ' ')
+      if (outputFile[i] == ' ' || outputFile[i] == ':')
 	outputFile[i] = '_';
-      if (outputFile[i] == '\n')
+      else if (outputFile[i] == '\n')
 	outputFile[i] = '\0';
     }
       
-  dataOutputFile = fopen(outputFile,"w");
+  if(!(dataOutputFile = fopen(outputFile,"w")))
+    abort();
   fprintf (dataOutputFile, "currentTime\t price\t\t dividend\t volume\n\n");
   return self;
 }
