@@ -1,7 +1,7 @@
+#include <misc.h> // random
 // Interface for random.m
 
 // Define the basic generator.  See random.m comments.
-extern long int random(void);
 #define RANDOM		random()
 #define MAXRAND         ((int)0x7fffffff)
 
