@@ -3,7 +3,7 @@
 // The random() generator is used for all random numbers.  It is set up to
 // be able to generate two sequences, a normal one and an auxiliary one.
 // The auxiliary one is used when a random numbers are temporarily needed
-// for display purposes (e.g. sampling the dividend sequence) without
+// for display purposes (e.g., sampling the dividend sequence) without
 // upsetting the reproducibility of the main simulation.  saveRandom()
 // and restoreRandom() respectively switch to and from the auxiliary
 // sequence.
@@ -64,13 +64,9 @@
 #include <math.h>
 #include <misc.h> // time_t
 
-#if 0
 // Prototypes for random() etc
-extern long random(void);
-extern void srandom (int seed);
-extern char *initstate (unsigned int seed, char *state, int n);
-extern char *setstate (char *state);
-#endif
+extern char *initstate (unsigned int seed, char *state, size_t n);
+extern char *setstate (const char *state);
 
 // Storage for random()'s two states.
 #define RANDOMBYTES	128
@@ -204,3 +200,16 @@ void restoreRandom(void)
     set = set_saved;
     gset = gset_saved;
 }
+
+
+
+
+
+
+
+
+
+
+
+
+
